==> org.opennms.features.distributed.kv-store.api-25.0.0-20190726.041734-1-sources.jar: org/opennms/features/distributed/kvstore/api/AbstractKeyValueStore.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2019 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2019 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.distributed.kvstore.api;

import java.util.Objects;
import java.util.concurrent.CompletableFuture;

/**
 * Skeleton implementation of {@link KeyValueStore} that defaults calls without ttl specified.
 */
public abstract class AbstractKeyValueStore implements KeyValueStore {
    @Override
    public final long put(String key, byte[] value, String context) {
        Objects.requireNonNull(key);
        Objects.requireNonNull(value);
        Objects.requireNonNull(context);

        return put(key, value, context, null);
    }

    @Override
    public final CompletableFuture<Long> putAsync(String key, byte[] value, String context) {
        Objects.requireNonNull(key);
        Objects.requireNonNull(value);
        Objects.requireNonNull(context);

        return putAsync(key, value, context, null);
    }
}

==> org.opennms.features.distributed.kv-store.api-25.0.0-20200122.025244-65-sources.jar: org/opennms/features/distributed/kvstore/api/AbstractKeyValueStore.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2019 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2019 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.distributed.kvstore.api;

import java.util.Objects;
import java.util.concurrent.CompletableFuture;

/**
 * Skeleton implementation of {@link KeyValueStore} that defaults calls without ttl specified.
 */
public abstract class AbstractKeyValueStore<T> implements KeyValueStore<T> {
    @Override
    public final long put(String key, T value, String context) {
        Objects.requireNonNull(key);
        Objects.requireNonNull(value);
        Objects.requireNonNull(context);

        return put(key, value, context, null);
    }

    @Override
    public final CompletableFuture<Long> putAsync(String key, T value, String context) {
        Objects.requireNonNull(key);
        Objects.requireNonNull(value);
        Objects.requireNonNull(context);

        return putAsync(key, value, context, null);
    }

    /**
     * A default truncate implementation.
     */
    @Override
    public void truncateContext(String context) {
        Objects.requireNonNull(context);

        enumerateContext(context).keySet().forEach(key -> delete(key, context));
    }
}
